==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/autoresponder/translations/autoresponder_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Tylko przy pierwszej wiadomości</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Odpowiadaj w konferencjach</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Niewidzialny</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Autoodpowiedź</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Treść autoodpowiedzi</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Wybierz status</translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>KADU AUTOODPOWIEDŹ:</translation>
    </message>
    <message>
        <source>I am busy.</source>
        <translation>Jestem zajęty.</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/autoresponder/translations/autoresponder_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Tylko przy pierwszej wiadomości</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Odpowiadaj w konferencjach</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Niewidzialny</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Autoodpowiedź</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Treść autoodpowiedzi</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Wybierz status</translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>KADU AUTOODPOWIEDŹ:</translation>
    </message>
    <message>
        <source>I am busy.</source>
        <translation>Jestem zajęty.</translation>
    </message>
</context>
</TS>
